==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/OperationResponseAssignmentOperationConfigurationActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OperationResponseAssignmentOperationConfigurationActions
 */
@JsonPropertyOrder({ OperationResponseAssignmentOperationConfigurationActions.JSON_PROPERTY_ASSIGN_USER_TO_REALM })
@JsonTypeName("OperationResponse_assignmentOperation_configuration_actions")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OperationResponseAssignmentOperationConfigurationActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ASSIGN_USER_TO_REALM = "assignUserToRealm";
    private OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm assignUserToRealm;

    public OperationResponseAssignmentOperationConfigurationActions() {
    }

    public OperationResponseAssignmentOperationConfigurationActions assignUserToRealm(
            OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm assignUserToRealm) {

        this.assignUserToRealm = assignUserToRealm;
        return this;
    }

    /**
     * Get assignUserToRealm
     *
     * @return assignUserToRealm
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_REALM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm getAssignUserToRealm() {
        return assignUserToRealm;
    }

    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_REALM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAssignUserToRealm(
            OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm assignUserToRealm) {
        this.assignUserToRealm = assignUserToRealm;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OperationResponseAssignmentOperationConfigurationActions operationResponseAssignmentOperationConfigurationActions = (OperationResponseAssignmentOperationConfigurationActions) o;
        return Objects.equals(this.assignUserToRealm,
                operationResponseAssignmentOperationConfigurationActions.assignUserToRealm);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(assignUserToRealm);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OperationResponseAssignmentOperationConfigurationActions {\n");
        sb.append("    assignUserToRealm: ").append(toIndentedString(assignUserToRealm)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/OperationResponseAssignmentOperationConfigurationActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OperationResponseAssignmentOperationConfigurationActions
 */
@JsonPropertyOrder({ OperationResponseAssignmentOperationConfigurationActions.JSON_PROPERTY_ASSIGN_USER_TO_REALM })
@JsonTypeName("OperationResponse_assignmentOperation_configuration_actions")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class OperationResponseAssignmentOperationConfigurationActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ASSIGN_USER_TO_REALM = "assignUserToRealm";
    private OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm assignUserToRealm;

    public OperationResponseAssignmentOperationConfigurationActions() {
    }

    public OperationResponseAssignmentOperationConfigurationActions assignUserToRealm(
            OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm assignUserToRealm) {

        this.assignUserToRealm = assignUserToRealm;
        return this;
    }

    /**
     * Get assignUserToRealm
     *
     * @return assignUserToRealm
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_REALM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm getAssignUserToRealm() {
        return assignUserToRealm;
    }

    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_REALM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAssignUserToRealm(
            OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm assignUserToRealm) {
        this.assignUserToRealm = assignUserToRealm;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OperationResponseAssignmentOperationConfigurationActions operationResponseAssignmentOperationConfigurationActions = (OperationResponseAssignmentOperationConfigurationActions) o;
        return Objects.equals(this.assignUserToRealm,
                operationResponseAssignmentOperationConfigurationActions.assignUserToRealm);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(assignUserToRealm);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OperationResponseAssignmentOperationConfigurationActions {\n");
        sb.append("    assignUserToRealm: ").append(toIndentedString(assignUserToRealm)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
